@@ -1,6 +1,4 @@
 /*
- * Copyright (C) 2005,2006 Russell Stuart
- *
  * conspy
  * ------
  *
@@ -15,20 +13,12 @@
  * License
  * -------
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
+ * Copyright (c) 2005,2006,2007,2008 Russell Stuart.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
  */
 #define	_GNU_SOURCE
 #include <curses.h>
@@ -49,13 +39,19 @@
 #include <sys/time.h>
 #include <unistd.h>
 
+/* GNU/kFreeBSD has different #define's */
+#if defined(__FreeBSD_kernel__)
+#define K_UNICODE K_CODE
+#define IUCLC 0
+#endif
+
 extern int errno;
 
 /*
  * Version info.
  */
-static char conspy_date[]	= "2006-01-14";
-static char conspy_version[]	= "1.4";
+static char conspy_date[]	= "2008-02-01";
+static char conspy_version[]	= "1.5";
 
 /*
  * VGA colour definitions, as found in a nibble in an attribute
